{% extends "djangoChat/base.html" %}
{% block body %}
	
<!--  chat box area -->
<section class="chatBox">
	
</section>





<!--  sidebar area -->
<section class="sidebar">
	<h4><a href="/chat/logout">logout</a></h4>
	<div class="side">
	<h2>Online Users</h2>
	<div class="onlineUsers">
		
		
			

	</div>
	</div>
</section>











<!--  input area  -->
<section class="input-area">
	<img width="64" height="64" src="{{user.profile.gravatar_url}}" alt="avatar" title="signup at gravatar.com with your email which is resgistered here to change your avatar">	
	<textarea class="input-box"></textarea>
	<button class="submit">send</button>
	<p class="clear-both"></p>
</section>



	

				

{% endblock body %}