<!DOCTYPE html>
<html>
  <head>
    <title>Django Chat Demo</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" type="text/css" href="/static/djangoChat/css/normalize.css" />
    <link href="/static/djangoChat/css/main.css" rel="stylesheet" type="text/css"/>
    <script data-main="/static/djangoChat/dist/scripts/main" type="text/javascript" src="/static/djangoChat/dist/scripts/vendor/requirejs/require.js"></script>
  </head>
  <body>
    {% block body %}
    <h1>Hello, world!</h1>
    


    {% endblock body %}
   
  </body>
</html>
